@@ -1,5 +1,6 @@
 import abc
-from typing import Type, List
+import io
+from typing import Type, List, Union
 
 from fastapi import UploadFile
 from pydantic import BaseModel
@@ -19,7 +20,7 @@ class ConverterBase(metaclass=abc.ABCMeta):
         pass
 
     @abc.abstractmethod
-    def convert(self, source: UploadFile, parameters: ConverterParameters) \
+    def convert(self, source: Union[io.IOBase, UploadFile], parameters: ConverterParameters) \
             -> List[Document]:
         """Parse the input source file and return a list of documents.
 
